rnalysis.filtering.DESeqFilter.filter\_by\_ref\_table\_attr
===========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.filter_by_ref_table_attr